@@ -19,9 +19,13 @@ def write_pdfgetter(saving_dir: str, filename: str, pdfgetter: PDFGetter) -> dic
             data_dir.mkdir()
         data_dirs.update({out_type: data_dir})
     dct = {}
-    for out_type in pdfgetter.config.outputtypes:  # out_type in ('iq', 'sq', 'fq', 'gr')
+    for (
+        out_type
+    ) in pdfgetter.config.outputtypes:  # out_type in ('iq', 'sq', 'fq', 'gr')
         data_dir = data_dirs.get(out_type)
-        out_file = data_dir.joinpath(Path(filename).with_suffix(".{}".format(out_type)).name)
+        out_file = data_dir.joinpath(
+            Path(filename).with_suffix(".{}".format(out_type)).name
+        )
         pdfgetter.writeOutput(str(out_file), out_type)
         dct.update({out_type: str(out_file)})
     return dct
