@@ -1,6 +1,3 @@
 from pdfstream.visualization.main import visualize, waterfall
 
-__all__ = [
-    "visualize",
-    "waterfall"
-]
+__all__ = ["visualize", "waterfall"]
