@@ -11,7 +11,7 @@ def test_savefig_factory():
     with TemporaryDirectory() as d:
         figure_forlder = Path(d) / "figures"
         savefig = savefig_factory(figure_dir=figure_forlder)
-        fname = 'test.png'
+        fname = "test.png"
         savefig(fname)
         figure_path = figure_forlder / fname
         assert figure_path.exists()
